## What is it?

A small custom library that simplifies and speeds up routine actions when 
working with pandas, scikitlearn, catboost, etc...

The project is actively developing in proportion to my experience


##  Documentation & definition

RUS - [colab.google_notebook](https://colab.research.google.com/drive/1umBPTHGfMzF7aYrcN5ZD6E-GX7s_iM8O?usp=share_link)

ENG - (in process)
